@@ -26,16 +26,20 @@ class Crop:
 def image_crop(
     image: Union[bytes, Image],
     crop: Optional[Crop] = None,
+    width_preview: Optional[int] = None,
     image_alt: Optional[str] = None,
     min_width: Optional[int] = None,
     min_height: Optional[int] = None,
     max_width: Optional[int] = None,
     max_height: Optional[int] = None,
-    keep_selection: Optional[bool] = None,
-    disabled: Optional[bool] = None,
-    locked: Optional[bool] = None,
+    # FIXME: Changing these properties, the component is rerendered unfortunately.
+    # ----
+    # keep_selection: Optional[bool] = None,
+    # disabled: Optional[bool] = None,
+    # locked: Optional[bool] = None,
     rule_of_thirds: Optional[bool] = None,
     circular_crop: Optional[bool] = None,
+    # ----
     key: Optional[str] = None,
 ) -> Optional[Image]:
     import dataclasses
@@ -43,7 +47,10 @@ def image_crop(
     from os import path
 
     import streamlit as st
+    from PIL.Image import composite as composite_image
+    from PIL.Image import new as new_image
     from PIL.Image import open as open_image
+    from PIL.ImageDraw import Draw
     from streamlit.components import v1 as components
     from streamlit.elements.image import image_to_url
 
@@ -76,9 +83,11 @@ def image_crop(
     else:
         image_ = open_image(BytesIO(image))
 
+    width, _ = image_.size
+
     src = image_to_url(
         image_,
-        width=500,
+        width=min(width, width_preview) if width_preview else width,
         clamp=False,
         channels="RGB",
         output_format="auto",
@@ -103,11 +112,14 @@ def image_crop(
         minHeight=min_height,
         maxWidth=max_width,
         maxHeight=max_height,
-        keepSelection=keep_selection,
-        disabled=disabled,
-        locked=locked,
+        # FIXME: Changing these properties, the component is rerendered unfortunately.
+        # ----
+        keepSelection=None,
+        disabled=None,
+        locked=None,
         ruleOfThirds=rule_of_thirds,
         circularCrop=circular_crop,
+        # ----
         crop=crop_,
         key=key,
         default=default,
@@ -125,4 +137,12 @@ def image_crop(
     if w_crop <= 0 or h_crop <= 0:
         return None
     else:
-        return image_.crop((x0, y0, x1, y1))
+        image_crop = image_.crop((x0, y0, x1, y1))
+        if circular_crop:
+            background = new_image("RGBA", (w_crop, h_crop), (0, 0, 0, 0))
+            mask = new_image("L", (w_crop, h_crop), 0)
+            draw = Draw(mask)
+            draw.ellipse((0, 0, w_crop, h_crop), fill="white")
+            image_crop = composite_image(image_crop, background, mask)
+
+        return image_crop
